@@ -8,6 +8,7 @@ from models import Journal, Tag, ObjectData, StringData
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
+from django.utils.html import escape
 from django.core.urlresolvers import reverse, NoReverseMatch
 
 import actions
@@ -95,7 +96,7 @@ class JournalAdmin(admin.ModelAdmin):
                 escape(entry.tag.id), escape(name))
         return res
     _tag.allow_tags = True
-    _tag.short_description = _('Tag')
+    _tag.short_description = _('tag')
 
     def ip(self, entry):
         '''Search and return any associated stringdata whose tag is "ip"'''
@@ -128,7 +129,7 @@ class JournalAdmin(admin.ModelAdmin):
         return u'<a href="?objectdata__content_type={0}&objectdata__object_id={1}">{2}</a>'.format(
                     objectdata.content_type_id,
                     objectdata.object_id,
-                    caption)
+                    escape(caption))
 
     def object_link(self, obj_data):
         if obj_data.content_object is None:
